# antpycv គឺជា Computer Vision package ដែលងាយស្រួលសរសេរកូដ python ភ្ជាប់ទៅកាន់ Arduino ដើម្បីធ្វើការបង្ហាញរូបភាពនិងកិច្ចការងារពាក់ព័ន្ធនឹងមុខងារ AI (Artificial Intelligence)។ antpycv ត្រូវបានបង្កើតឡើងដោយប្រើប្រាស់ OpenCV និង Mediapipe libraries។
## អ្នកអាចធ្វើការតំឡើង antpycv package ទៅកាន់ virtual environment (venv) project របស់អ្នកតាមរយៈ command ខាងក្រោម៖
### pip install antpycv ###

## ជាការសំនូមពរអ្នកគួរតែធ្វើការ upgrade តាម command ខាងក្រោម៖
### pip install --upgrade pip setuptools wheel ###
